@@ -19,8 +19,8 @@ helper_detect_os <- function(){
 # Make names for search results
 #
 # @param mySearchResults Data frame; data frame containing search results.
-# @param resultidprefix Character string; prefix for the name of the consecutively numbered search results.
-# 
+# @param resultid.prefix Character string; prefix for the name of the consecutively numbered search results.
+# @param resultid.start Integer; start number of results 
 # @return Vector of character strings; names created for the search results.
 # @export
 #
@@ -32,20 +32,22 @@ helper_detect_os <- function(){
 # searchresults <- act::search_corpus(examplecorpus, pattern=myRegEx, concordanceMake=FALSE)
 # 
 # # Make custom names
-# mynames <- act::search_names(searchresults, resultidprefix="yo")
+# mynames <- act::search_names(searchresults, resultid.prefix="yo")
 # 
 # # Replace old names in search by new names
 # searchresults$resultID <- mynames
 # @keywords internal
 helper_makeNamesForSearch <- function(mySearchResults, 
-									  resultidprefix="result") {
+									  resultid.prefix = "result",
+									  resultid.start  = 1) {
 	
-	myFormat <- paste(resultidprefix, "%0", nchar(toString(nrow(mySearchResults))), "d", sep="")
-	myNames <- sprintf(myFormat, 1:nrow(mySearchResults))
+	myFormat <- paste(resultid.prefix, "%0", nchar(toString(nrow(mySearchResults)-1+resultid.start)), "d", sep="")
+	myNames <- sprintf(myFormat, resultid.start:(nrow(mySearchResults)+resultid.start-1))
 	return (myNames)
 }
 
 
+
 # Gets the path of a .TextGrid for a transcript
 #
 # Returns either the path to the original .TextGrid file or to a temporary TextGrid created on the fly.
@@ -122,7 +124,7 @@ helper_progress_set <- function(title, total) {
 			if(exists("pb", envir=act.environment)) {
 				title <- stringr::str_pad(title, width=24, side="right", pad=" ")
 				act.environment$pb <- progress::progress_bar$new(
-					format = paste("  ", title, "[:bar] :percent missing: :eta", sep=""),
+					format = paste("  ", title, "[:bar] :percent (:eta left)", sep=""),
 					total = total, 
 					clear = FALSE, 
 					show_after = 0,
