@@ -14,7 +14,7 @@
 #' examplecorpus <- act::media_delete(examplecorpus)
 #' 
 media_delete <- function(x, transcriptNames=NULL) {
-	if (missing(x)) 	{stop("Corpus object in parameter 'x' is missing.") 		} else { if (class(x)[[1]]!="corpus") 		{stop("Parameter 'x' needs to be a corpus object.") 	} }
+	if (missing(x)) 	{stop("Corpus object in parameter 'x' is missing.") 		}	else { if (!methods::is(x,"corpus")   )	{stop("Parameter 'x' needs to be a corpus object.") } }
 	
 	#  if no filter is set, process all transcripts
 	if (is.null(transcriptNames)) {transcriptNames <- names(x@transcripts)}
