@@ -18,19 +18,19 @@ library(act)
 	# Get entire cut list for Mac and display on screen, 
 	# so you can copy&paste this into the Terminal
 	mycutlist <- mysearch@cuts.cutlist.mac 
-	cat(stringr::str_c(mycutlist, sep="\n", collapse = "\n"))
+	cat(mycutlist)
 	# Cut list for first search result
 	mycutlist <- mysearch@results$cuts.cutlist.mac[[1]]
-	cat(stringr::str_c(mycutlist, sep="\n", collapse = "\n"))
+	cat(mycutlist)
 	
 	# Check results for Windows:
 	# Get entire cut list for Mac and display on screen, 
 	# so you can copy&paste this into the CLI
 	mycutlist <- mysearch@cuts.cutlist.win 
-	cat(stringr::str_c(mycutlist, sep="\n", collapse = "\n"))
+	cat(mycutlist)
 	# Cut list for first search result
 	mycutlist <- mysearch@results$cuts.cutlist.win[[1]]
-	cat(stringr::str_c(mycutlist, sep="\n", collapse = "\n"))
+	cat(mycutlist)
 	
 	# It is, however, more convenient to specify the argument 'outputFolder' in order to get
 	# the cut list as a (executable) file/batch list.
